@@ -51,10 +51,7 @@ class DistilBertEncoder:
             self._pretrained_model_name = 'distilbert-base-uncased'
             self._model_max_len = 768
 
-        device_str = "cuda" if CONFIG.USE_CUDA else "cpu"
-        if CONFIG.USE_DEVICE is not None:
-            device_str = CONFIG.USE_DEVICE
-        self.device = torch.device(device_str)
+        self.device, _ = get_devices()
 
     def _train_callback(self, error, real_buff, predicted_buff):
         logging.info(f'{self.name} reached a loss of {error} while training !')
@@ -97,6 +94,14 @@ class DistilBertEncoder:
 
         return loss
 
+    def to(self, device, available_devices):
+        self._model = self._model.to(self.device)
+
+        if self._head is not None:
+            self._head = self._head.to(self.device)
+
+        return self
+
     def prepare_encoder(self, priming_data, training_data=None):
         if self._prepared:
             raise Exception('You can only call "prepare_encoder" once for a given encoder.')
